package com.bayread.sensors.service;

import com.bayread.sensors.batch.BatchWorkerCollector;
import com.bayread.sensors.conf.ServiceConfig;
import com.bayread.sensors.task.LogsHandleWorker;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

@Slf4j
@Controller
@RequestMapping(value = "/")
public class APIService {
    private final static String OK_RESULT = "";

    private static BatchWorkerCollector<String> workerCollector;

    private static final Logger TRACKING_EVENT = LoggerFactory.getLogger("tracking.event");

    @Resource
    private ServiceConfig conf;

    @Resource
    private KafkaTemplate<String, String> kafka;

    @PostConstruct
    private void init() {
        workerCollector = new BatchWorkerCollector<>(
                "LogsHandleWorker", conf.queueSize, conf.workQueueSize, conf.threadSize, conf.batchSize, conf.pollWaitTime, new LogsHandleWorker(kafka));
        workerCollector.start();
    }

    @ResponseBody
    @RequestMapping(value = "sa")
    public String app(HttpServletRequest request) {

       String dataList = request.getParameter("data_list");

       if(StringUtils.isNotEmpty(dataList)){
           TRACKING_EVENT.info(dataList);
           workerCollector.put(dataList);
       }

       return OK_RESULT;
    }

    @ResponseBody
    @RequestMapping(value = "web")
    public String dy(HttpServletRequest request) {
        String dataList = new InputStreamToString(request).get();

        if(StringUtils.isNotEmpty(dataList)){
            TRACKING_EVENT.info(dataList);
            workerCollector.put(dataList);
        }

        return OK_RESULT;
    }

    @ResponseBody
    @RequestMapping(value = "sa.gif")
    public String jsweb(HttpServletRequest request) {
        String data = request.getParameter("data");

        if(StringUtils.isNotEmpty(data)){
            data = "data_jweb=".concat(data);
            TRACKING_EVENT.info(data);
            workerCollector.put(data);
        }

        return OK_RESULT;
    }


    @ResponseBody
    @RequestMapping(value = "ping")
    public String test() {
        return OK_RESULT;
    }
}