package com.bayread.sensors.service;

/**
 * @author martin.ad
 * @Description:
 * @date 创建时间： 2022/11/7 14:48
 */

import lombok.extern.slf4j.Slf4j;
import org.apache.catalina.connector.ClientAbortException;
import org.apache.commons.compress.compressors.gzip.GzipCompressorInputStream;

import javax.servlet.http.HttpServletRequest;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.StandardCharsets;
import java.util.Objects;

@Slf4j
public class InputStreamToString {

    public static final String GZIP_ENCODE_UTF_8 = "UTF-8";

    public static final int BUFFER_SIZE = 1024;

    private InputStream in;

    private boolean isCompress = false;

    public InputStreamToString(HttpServletRequest request){
        try {
            this.in = request.getInputStream();
        } catch (IOException e) {
            log.error("request.getInputStream()",e);
        }
        String encode = request.getHeader("Content-Encoding");
        if(!Objects.isNull(encode) && encode.trim().equals("gzip")){
            isCompress = true;
        }
    }

    public String get(){
        return isCompress?gzipStreamToString():streamToString();
    }

    private String gzipStreamToString() {
        try (ByteArrayOutputStream out = new ByteArrayOutputStream();
             GzipCompressorInputStream gin = new GzipCompressorInputStream(in)){
            final byte[] buffer = new byte[BUFFER_SIZE];
            int n = 0;
            while (-1 != (n = gin.read(buffer))) {
                out.write(buffer, 0, n);
            }
            return out.toString(GZIP_ENCODE_UTF_8);
        } catch (IOException e) {
            log.error("gzipStreamToString error",e);
        }
        return null;
    }

    private String streamToString() {
        try (ByteArrayOutputStream out = new ByteArrayOutputStream()){
            final byte[] buffer = new byte[BUFFER_SIZE];
            int n = 0;
            while (-1 != (n = in.read(buffer))) {
                out.write(buffer, 0, n);
            }
            return new String(out.toByteArray(), StandardCharsets.UTF_8);
        } catch (IOException e) {
            log.error("streamToString error",e);
        }
        return null;
    }
}
