package com.bayread.sensors.task;

import cn.hutool.core.util.ZipUtil;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.bayread.sensors.batch.impl.MultipleWorkerEvent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.kafka.core.KafkaTemplate;
import sun.misc.BASE64Decoder;

import java.io.IOException;
import java.net.URLDecoder;
import java.nio.charset.StandardCharsets;
import java.util.List;

public class LogsHandleWorker implements MultipleWorkerEvent<String> {
    private static final Logger ADAPTER_ERROR_LOG = LoggerFactory.getLogger("adapter.error");
    private static final Logger SYS_ERROR_LOG = LoggerFactory.getLogger("sys.error");
//    private static final String TOPIC = "ets_app_topic";
    private static final String TOPIC = "event_topic";
    private KafkaTemplate<String, String> kafka;

    public LogsHandleWorker(KafkaTemplate<String, String> kafka){
        this.kafka = kafka;
    }

    @Override
    public void handle(List<String> list) {
        if(list.size() == 0){return;}

        list.forEach(log ->{
            try {
                if(log.startsWith("data_jweb=")){
                    jsweb(log);
                }else if(log.startsWith("data_list=")){
                    web(log);
                }else{
                    app(log);
                }
            }catch (Exception ex){
                ADAPTER_ERROR_LOG.info("ERROR LOG:{}",log);
                ex.printStackTrace();
            }
        });
    }

    void app(String logs) throws IOException {
        BASE64Decoder decoder = new BASE64Decoder();
        byte[] dbyte = decoder.decodeBuffer(logs);

        JSONArray ja = JSON.parseArray(new String(ZipUtil.unGzip(dbyte), StandardCharsets.UTF_8));

        for(int i=0;i<ja.size();i++) {
            send(ja.getJSONObject(i).toString());
        }
    }

    void web(String logs) throws IOException{
        String params = URLDecoder.decode(logs.substring(10),"UTF-8");
        BASE64Decoder decoder = new BASE64Decoder();
        byte[] dbyte = decoder.decodeBuffer(params);

        JSONArray ja = JSON.parseArray(new String(dbyte, StandardCharsets.UTF_8));

        for(int i=0;i<ja.size();i++) {
            send(ja.getJSONObject(i).toString());
        }
    }

    void jsweb(String logs) throws IOException{
        String params = URLDecoder.decode(logs.substring(10),"UTF-8");
        BASE64Decoder decoder = new BASE64Decoder();
        byte[] dbyte = decoder.decodeBuffer(params);
        send(new String(dbyte, StandardCharsets.UTF_8));
    }

    public void send(String log){
        kafka.send(TOPIC, log);
    }

    @Override
    public void handleException(Object obj, Exception ex) {
        SYS_ERROR_LOG.error("LogsHandleWorker Exception:",ex);
    }
}